@@ -15,6 +15,10 @@ run_controlled ()
 	[ -z "$3" ] && die_error "run_controlled needs a logfile to redirect output to!"
 	[ -z "$4" ] && die_error "run_controlled needs a title to show while your process is running!"
 	
+	log_parent=$(dirname $3)
+	if [ ! -d $log_parent ]; then
+		mkdir -p $log_parent || die_error "Could not create $log_parent, we were asked to log $1 to $3"
+	fi
 	if [ "$var_UI_TYPE" = dia ]
 	then
 		run_background $1 "$2" $3
@@ -41,6 +45,11 @@ run_background ()
 	[ -z "$2" ] && die_error "run_background needs a command to execute!"
 	[ -z "$3" ] && die_error "run_background needs a logfile to redirect output to!"
 
+	log_parent=$(dirname $3)
+	if [ ! -d $log_parent ]; then
+		mkdir -p $log_parent || die_error "Could not create $log_parent, we were asked to log $1 to $3"
+	fi
+
 	debug 'MISC' "run_background called. identifier: $1, command: $2, logfile: $3"
 	( \
 		touch $RUNTIME_DIR/aif-$1-running
@@ -80,14 +89,12 @@ wait_for ()
 check_is_in ()
 {
 	[ -z "$1" ] && die_error "check_is_in needs a non-empty needle as \$1 and a haystack as \$2!(got: check_is_in '$1' '$2'" # haystack can be empty though
-	NEEDLE=$1
-	HAYSTACK=$2
 
-	local pattern="$NEEDLE" element
+	local needle="$1" element
 	shift
 	for element
 	do
-		[[ $element = $pattern ]] && return 0
+		[[ $element = $needle ]] && return 0
 	done
 	return 1
 }
@@ -105,13 +112,13 @@ cleanup_runtime ()
 # $2 direction (systohc or hctosys)
 dohwclock() {
 	# TODO: we probably only need to do this once and then actually use adjtime on next invocations
-	infofy "Resetting hardware clock adjustment file"
+	inform "Resetting hardware clock adjustment file"
 	[ ! -d /var/lib/hwclock ] && mkdir -p /var/lib/hwclock
 	if [ ! -f /var/lib/hwclock/adjtime ]; then
 		echo "0.0 0 0.0" > /var/lib/hwclock/adjtime
 	fi
 
-	infofy "Syncing clocks ($2), hc being $1 ..."
+	inform "Syncing clocks ($2), hc being $1 ..."
 	if [ "$1" = "UTC" ]; then
 		hwclock --$2 --utc
 	else
