@@ -13,9 +13,9 @@ ui_init ()
 		logs=$LOG
 	fi
 	if [ "$DEBUG" = '1' ]; then
-		libui-sh-init ${var_UI_TYPE:-cli} "$RUNTIME_DIR" "$logs" "${cats[@]}"
+		libui_sh_init ${var_UI_TYPE:-cli} "$RUNTIME_DIR" "$logs" "${cats[@]}"
 	else
-		libui-sh-init ${var_UI_TYPE:-cli} "$RUNTIME_DIR" "$logs"
+		libui_sh_init ${var_UI_TYPE:-cli} "$RUNTIME_DIR" "$logs"
 	fi
 
 	# get keymap/font (maybe configured by aif allready in another process or even in another shell)
